==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PL/ts/Arc2PL_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Arc2PL</name>
    <message>
        <location filename="../Arc2PL.js" line="+65"/>
        <source>Start point</source>
        <translation>開始点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>終了点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>２点は同一です</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>The distance between the two points must be less than the arc length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PL.ui" line="+17"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>向き:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>反時計回り（正）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>時計回り（負）</translation>
    </message>
    <message>
        <location filename="../Arc2PLInit.js" line="+2"/>
        <source>&amp;2 Points and Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PL/ts/Arc2PL_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Arc2PL</name>
    <message>
        <location filename="../Arc2PL.js" line="+65"/>
        <source>Start point</source>
        <translation>開始点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>終了点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid length</source>
        <translation>無効な長さ</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>２点は同一です</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>The distance between the two points must be less than the arc length</source>
        <translation>２点の距離は弧の長さより小さくなければなりません。</translation>
    </message>
    <message>
        <location filename="../Arc2PL.ui" line="+17"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>向き:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>反時計回り（正）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>時計回り（負）</translation>
    </message>
    <message>
        <location filename="../Arc2PLInit.js" line="+2"/>
        <source>&amp;2 Points and Length</source>
        <translation>２点と長さ</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and length</source>
        <translation>２点と長さから弧を描く</translation>
    </message>
</context>
</TS>
